# Function to get file from servcat

get_file_from_servcat <- function(file_number, 
                                  download_dir = tempdir(check = TRUE)
) {
  
  # Make sure desired directory exists
  if (!dir.exists(download_dir)) dir.create(download_dir)
  
  # Set up file download API endpoint - we could do this with just trying to use
  # the https://ecos.fws.gov/ServCat/DownloadFile/ URL scheme, but if/when it 
  # breaks we don't get any useful information, unlike the API. See 
  # https://ecos.fws.gov/ServCatServices/servcat/v4/documentation/servcat-api.html#/Download_File
  public_api <- "https://ecos.fws.gov/ServCatServices/servcat/v4"
  private_api <- "https://ecos.fws.gov/ServCatServices/servcat-secure/v4"
  download_endpoint <- "/rest/DownloadFile/"
  api_build_endpoint <- "/rest/ServiceVersion"
  
  # Check to make sure we can see ServCat and get data from it. If it fails we
  # will get an error here (that is, if we get status != 200). We can ignore
  # a successful request, we don't need the results
  httr2::request(private_api) |>
    httr2::req_options(httpauth = 4L, userpwd = ":::") |>
    httr2::req_url_path_append(api_build_endpoint) |>
    httr2::req_perform() |> 
    httr2::resp_check_status()
  
  # Generate a temporary file name - we don't really care about the csv file 
  # and it will be removed after this R session
  temp_csv <- tempfile(fileext = ".csv")
  
  # Build the request and download the file. Halt if this fails
  httr2::request(private_api) |>
    httr2::req_url_path_append(download_endpoint) |>
    httr2::req_url_path_append(file_number) |>
    httr2::req_options(httpauth = 4L, userpwd = ":::") |>
    httr2::req_perform(path = temp_csv) |> 
    httr2::resp_check_status()
  
  return(temp_csv)
}
